/*
 * Guifications - The end all, be all, toaster popup plugin
 * Copyright (C) 2003-2004 Gary Kramlich
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
#ifdef HAVE_CONFIG_H
# include "../gf_config.h"
#endif

#define GAIM_PLUGINS

#include "gf_action.h"
#include "gf_blist.h"
#include "gf_display.h"
#include "gf_event.h"
#include "gf_gtk_utils.h"
#include "gf_internal.h"
#include "gf_item_text.h"
#include "gf_preferences.h"
#include "gf_theme.h"
#include "gf_theme_editor.h"
#include "gf_stock.h"

#include <debug.h>
#include <gaim.h>
#include <plugin.h>
#include <gtkplugin.h>
#include <version.h>

static gboolean
gf_load(GaimPlugin *plugin) {

	gf_actions_init();
	gf_blist_init(plugin);
	gf_events_init(plugin);
	gf_theme_editor_init(plugin);
	gf_item_text_init();
	gf_display_init(plugin);
	gf_gtk_utils_init();
	gf_stock_init();
	gf_themes_probe();
	gf_themes_load_saved();

	return TRUE;
}

static gboolean
gf_unload(GaimPlugin *plugin) {
	gf_stock_uninit();
	gf_themes_unprobe();
	gf_themes_save_loaded();
	gf_themes_unload();
	gf_gtk_utils_uninit();
	gf_display_uninit();
	gf_item_text_uninit();
	gf_theme_editor_uninit();
	gf_events_uninit();
	gf_blist_uninit();
	gf_actions_uninit();

	return TRUE;
}

static GaimGtkPluginUiInfo ui_info = { gf_preferences_get_frame };

static GaimPluginInfo gf_info = {
	GAIM_PLUGIN_MAGIC,								/* plugin magic	*/
	GAIM_MAJOR_VERSION,								/* major gaim version	*/
	GAIM_MINOR_VERSION,								/* minor gaim version	*/
	GAIM_PLUGIN_STANDARD,							/* type			*/
	GAIM_GTK_PLUGIN_TYPE,							/* ui requirement	*/
	0,												/* flags			*/
	NULL,											/* dependencies	*/
	GAIM_PRIORITY_DEFAULT,							/* priority		*/

	"gtk-amc_grim-Guifications",					/* id			*/
	NULL,											/* name			*/
#ifdef _WIN32
	GF_VERSION,
#else
	VERSION,										/* version		*/
#endif
	NULL,											/* summary		*/
	NULL,											/* description	*/

	"Gary Kramlich <amc_grim@users.sf.net>",		/* author		*/
	GF_WEBSITE,										/* homepage		*/

	gf_load,										/* load			*/
	gf_unload,										/* unload		*/
	NULL,											/* destroy		*/

	&ui_info,										/* ui info		*/
	NULL,											/* extra info		*/
	NULL,											/* plugin prefs	*/
	NULL											/* plugin actions	*/
};

static void
init_plugin(GaimPlugin *plugin) {
	
#ifdef ENABLE_NLS
	bindtextdomain(GF_PACKAGE, LOCALEDIR);
	bind_textdomain_codeset(GF_PACKAGE, "UTF-8");
#endif /* ENABLE_NLS */
	
	gf_info.name		= _("Guifications");
	gf_info.summary		= _("The end all, be all, toaster popup plugin");
	gf_info.description	= _("Guifications:\n"
							"The end all, be all, toaster popup plugin");
	gf_preferences_add();
}

GAIM_INIT_PLUGIN(Guifications2, init_plugin, gf_info)
